summaryrefslogtreecommitdiffstats
path: root/include/linux
diff options
context:
space:
mode:
authorRicardo Ribalda Delgado2013-08-14 23:23:50 +0200
committerBryan Wu2013-08-27 02:22:14 +0200
commit56a1740c21e4396164265c3ec80e29990ddcdc36 (patch)
tree5b8de09166080cb6479811c7436e57b8788434cd /include/linux
parentleds-pca9633: Add mutex to the ledout register (diff)
downloadkernel-qcow2-linux-56a1740c21e4396164265c3ec80e29990ddcdc36.tar.gz
kernel-qcow2-linux-56a1740c21e4396164265c3ec80e29990ddcdc36.tar.xz
kernel-qcow2-linux-56a1740c21e4396164265c3ec80e29990ddcdc36.zip
leds-pca9633: Rename to leds-pca963x
The driver now supports the chips pca9633 and pca9634, therefore we rename the files to more generic and meaningul names Signed-off-by: Ricardo Ribalda Delgado <ricardo.ribalda@gmail.com> Signed-off-by: Bryan Wu <cooloney@gmail.com>
Diffstat (limited to 'include/linux')
-rw-r--r--include/linux/platform_data/leds-pca963x.h (renamed from include/linux/platform_data/leds-pca9633.h)27
1 files changed, 14 insertions, 13 deletions
diff --git a/include/linux/platform_data/leds-pca9633.h b/include/linux/platform_data/leds-pca963x.h
index 3c1037a81d34..e731f0036329 100644
--- a/include/linux/platform_data/leds-pca9633.h
+++ b/include/linux/platform_data/leds-pca963x.h
@@ -1,7 +1,8 @@
/*
* PCA9633 LED chip driver.
*
* Copyright 2012 bct electronic GmbH
+ * Copyright 2013 Qtechnology A/S
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
@@ -18,24 +19,24 @@
* 02110-1301 USA
*/
-#ifndef __LINUX_PCA9633_H
-#define __LINUX_PCA9633_H
+#ifndef __LINUX_PCA963X_H
+#define __LINUX_PCA963X_H
#include <linux/leds.h>
-enum pca9633_outdrv {
- PCA9633_OPEN_DRAIN,
- PCA9633_TOTEM_POLE, /* aka push-pull */
+enum pca963x_outdrv {
+ PCA963X_OPEN_DRAIN,
+ PCA963X_TOTEM_POLE, /* aka push-pull */
};
-enum pca9633_blink_type {
- PCA9633_SW_BLINK,
- PCA9633_HW_BLINK,
+enum pca963x_blink_type {
+ PCA963X_SW_BLINK,
+ PCA963X_HW_BLINK,
};
-struct pca9633_platform_data {
+struct pca963x_platform_data {
struct led_platform_data leds;
- enum pca9633_outdrv outdrv;
- enum pca9633_blink_type blink_type;
+ enum pca963x_outdrv outdrv;
+ enum pca963x_blink_type blink_type;
};
-#endif /* __LINUX_PCA9633_H*/
+#endif /* __LINUX_PCA963X_H*/
@@ -1,7 +1,8 @@
/*
- * PCA9633 LED chip driver.
+ * PCA963X LED chip driver.
*
* Copyright 2012 bct electronic GmbH